@@ -440,7 +440,7 @@ def raw_values(kpath, reader):
         yield line
 
 
-def list_sections(kpath, reader):
+def list_sections(reader):
     """
     Return list of sections found by *reader*.
     """
